==> igniteui-angular-charts-14.1.1.tgz: package/esm2015/lib/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ChaikinOscillatorIndicator = /*@__PURE__*/ (() => {
    class ChaikinOscillatorIndicator extends StrategyBasedIndicator {
        get_uh() {
            return new ChaikinOscillatorIndicatorStrategy();
        }
        get uh() {
            return this.get_uh();
        }
        get_uu() {
            return ChaikinOscillatorIndicator.$;
        }
        get uu() {
            return this.get_uu();
        }
        get shortPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.u3));
        }
        set shortPeriod(a) {
            this.h(ChaikinOscillatorIndicator.u3, a);
        }
        up() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.u2));
        }
        set longPeriod(a) {
            this.h(ChaikinOscillatorIndicator.u2, a);
        }
        um() {
            return this.longPeriod;
        }
    }
    ChaikinOscillatorIndicator.$t = markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    ChaikinOscillatorIndicator.u3 = StrategyBasedIndicator.u1(3, ChaikinOscillatorIndicator.$);
    ChaikinOscillatorIndicator.u2 = StrategyBasedIndicator.ux(10, ChaikinOscillatorIndicator.$);
    return ChaikinOscillatorIndicator;
})();

==> igniteui-angular-charts-16.0.0.tgz: package/esm2015/lib/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ChaikinOscillatorIndicator = /*@__PURE__*/ (() => {
    class ChaikinOscillatorIndicator extends StrategyBasedIndicator {
        get_ul() {
            return new ChaikinOscillatorIndicatorStrategy();
        }
        get ul() {
            return this.get_ul();
        }
        get_uy() {
            return ChaikinOscillatorIndicator.$;
        }
        get uy() {
            return this.get_uy();
        }
        get shortPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.u7));
        }
        set shortPeriod(a) {
            this.h(ChaikinOscillatorIndicator.u7, a);
        }
        ut() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.u6));
        }
        set longPeriod(a) {
            this.h(ChaikinOscillatorIndicator.u6, a);
        }
        uq() {
            return this.longPeriod;
        }
    }
    ChaikinOscillatorIndicator.$t = markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    ChaikinOscillatorIndicator.u7 = StrategyBasedIndicator.u5(3, ChaikinOscillatorIndicator.$);
    ChaikinOscillatorIndicator.u6 = StrategyBasedIndicator.u1(10, ChaikinOscillatorIndicator.$);
    return ChaikinOscillatorIndicator;
})();
